@@ -9,7 +9,6 @@ import cloudevents.http
 from .locate import FindFunc, ArgumentConversion
 
 
-
 def WrapFunction(func: typing.Callable) -> typing.Callable:
     sig = inspect.signature(func)
     args = [ArgumentConversion(p) for p in sig.parameters.values()]
@@ -20,7 +19,7 @@ def WrapFunction(func: typing.Callable) -> typing.Callable:
         event = None
         if need_cloudevent:
             event = cloudevents.http.from_http(req.headers, req.get_data())
-        
+
         params = {arg.name: arg.convert(req, event) for arg in args}
 
         result = func(**params)
@@ -29,13 +28,25 @@ def WrapFunction(func: typing.Callable) -> typing.Callable:
             return result
 
         if need_cloudevent and result:
+            if not isinstance(result, cloudevents.http.CloudEvent):
+                try:
+                    if isinstance(result, tuple):
+                        result = cloudevents.http.CloudEvent(*result)
+                    else:
+                        result = cloudevents.http.CloudEvent(result)
+                except Exception as e:
+                    traceback.print_exc()
+                    # Opportunistic conversion; failures will be caught in the next block
+                    pass
             try:
                 headers, body = cloudevents.http.to_binary(result)
                 return flask.Response(body, 200, headers)
             except Exception as e:
-                print(f"Unable to decode result: {e}")
+                print(f"Sending raw result: {e}")
                 traceback.print_exc()
-                result = "Accepted with no event response"
+                return flask.Response(
+                    "Accepted with no event response", 200, mimetype="text/plain"
+                )
 
         return flask.Response(result, 200)
 
@@ -48,6 +59,5 @@ def main():
     http_func = WrapFunction(func)
     # TODO: add option for GET / handle multiple functions
     app = flask.Flask(func.__name__)
-    app.add_url_rule("/",view_func=http_func, methods=['POST'])
+    app.add_url_rule("/", view_func=http_func, methods=["POST"])
     app.run(host="0.0.0.0", port=os.environ.get("PORT", 8080))
-
